@@ -40,7 +40,7 @@ from cStringIO import StringIO
 
 python_version = '.'.join(str(x) for x in sys.version_info[:2])
 if python_version not in ('2.4', '2.5','2.6'):
-    warnings.warn('byteplay supports only Python versions 2.4 and 2.5 and 2.6')
+    warnings.warn('byteplay supports only Python versions 2.4 and 2.5 , 2.6')
 
 class Opcode(int):
     """An int which represents an opcode - has a nicer repr."""
@@ -113,7 +113,8 @@ class _se:
     DELETE_SLICE_0, DELETE_SLICE_1, DELETE_SLICE_2, DELETE_SLICE_3 = \
         (1,0),(2,0),(2,0),(3,0)
 
-    STORE_SUBSCR = 3,0
+    STORE_MAP = 2,0
+    STORE_SUBSCR = 2,2
     DELETE_SUBSCR = STORE_ATTR = 2,0
     DELETE_ATTR = STORE_DEREF = 1,0
     PRINT_NEWLINE = 0,0
