@@ -7,6 +7,14 @@ PREFIX = normpath(dirname(dirname(abspath(__file__))))
 if PREFIX not in sys.path:
     sys.path=[PREFIX] + sys.path
 
+#数据库配置
+DATABASE_CONFIG = {
+    "wtree": {
+        "master": "localhost:3306:wtree:root:111111",
+        "tables": ["*","user"],
+    },
+}
+
 #是否启用在线调试
 DEBUG = True
 
@@ -25,7 +33,14 @@ FILE_HOST = ""
 #Javascript文件服务器的域名
 JS_FILE_HOST = ""
 
+#Memcache的地址
+MEMCACHED_ADDR = None
+#MEMCACHED_ADDR = ["127.0.0.1:11211"]
+
+#是否禁用进程内缓存
+DISABLE_LOCAL_CACHED = False
+
 try:
     from local_config import *
 except ImportError:
-    print "WARNING : local_config not exist"
\ No newline at end of file
+    print "WARNING : local_config not exist"
