@@ -1,3 +1,6 @@
+#coding:utf-8
+from init_db import McModel,Model
+
 class UserGroup(McModel):    #id user_id group
     pass
 
